/* Title: Control Structure
   Name: Eric Walsh
   Description: This procedure contains the structure for setting up a control
		in an editable listbox.
		Also included is a complete list of all messages that are sent
		to and recieved from an editable listbox.
*/

#ifndef _EDLB_H
#define _EDLB_H 1

/* The EDLB_MSG structure is used with some communication to the editable */
/* listbox. */

typedef struct edlb_msg
{
	WORD col_id;         // ID of column, not position, position can change
	LONG row_num;        // Index of row.
	LONG data;           // Can be string pointer, bitmap handle etc.
} EDLB_MSG;

/* CONTROL - Specifies the layout (size, characteristics) of each column */

typedef struct control
{
	int  width;          // Width of the column
	int  datatype;       // Format of data (string default, numeric etc). See Data Style
	long flags;          // creation parameters
	WORD column_id;      // ID, for use with addstring, insertstring, etc
	char *heading;       // Column heading, use ECS_COLUMNHEADING
	long hflags;         // Flags on how to align heading text
} CONTROL;

typedef struct edlb_compareitemstruct
{
	UINT  CtlID;        // ID of column being sorted
	HWND  hWndItem;     // Handle of window being sorted
	WORD  ColID;        // Col id of column being sorted
	WORD  rownum1;      // First row being compared
	LONG  celldata1;    // Text in first cell
	WORD  rownum2;      // Second row being compared
	LONG  celldata2;    // Text in second cell
} EDLB_COMPAREITEMSTRUCT;

#define CTLCOLOR_ELB     7
#define COLUMNSEP        '\t'

/**** The following is the control creation flags for the editable listbox ***/

#define ELS_MOVEABLECOLUMNS	0x00000001L
#define ELS_RESIZECOLUMNS		0x00000002L
#define ELS_MULTICOLUMN			0x00000004L
#define ELS_MULTIPLESEL			0x00000008L
#define ELS_READONLY				0x00000010L
#define ELS_ROWADDRESSABLE    0x00000020L                                                           
#define ELS_DRAGDROPSERVER    0x00000040L
#define ELS_SORT					0x00000080L
#define ELS_NUMERICROWLABEL   0x00000100L

/************ Description of above control creation flags **********************

ELS_MOVEABLECOLUMNS - Allows columns to be moved within the editable listbox
ELS_RESIZECOLUMNS   - Allows columns to be resized within the editable listbox
ELS_MULTICOLUMN     - States that the editable listbox will have multiple columns
						  - Must provide EL_CONTROLSTRCT message.
ELS_MULTISEL        - Allows user to select a range of rows and columns.
ELS_READONLY        - Prevents allowing in cell editing
ELS_ROWADDRESSABLE  - In a multicolumn editable listbox this flag will cause the
							 entire row to be selected when a mouse is depressed in any
							 cell.
ELS_DRAGDROPSERVER  - Tells the control that it is able to be a drag and drop
							 server to other controls.  The WM_EX_ACCEPTFILES windows
							 flag indicates the the control can accept files.
ELS_SORT            - States that the editable listbox is sortable.
ELS_NUMERICROWLABEL - Labels each row starting with one. 
/******************************************************************************/

/* Below are the various column creation style types */

#define ECS_BORDER            0x00000001L
#define ECS_CENTER 				0x00000002L
#define ECS_RIGHT 				0x00000004L
#define ECS_AUTOHSCROLL       0x00000008L
#define ECS_COLUMNHEADING     0x00000010L
#define ECS_READONLY          0x00000020L
#define ECS_HIDDEN            0x00000040L
#define ECS_SORT              0x00000080L
#define ECS_DESCENDSORT       0x00000100L
#define ECS_OWNERSORT         0x00000200L
#define ECS_NORESIZECOLUMN    0x00000400L

/* Below are the various column creation style types - Values should not be */
/* Or-ed together. */

#define ECS_STRING            0x0001
#define ECS_NUMERIC           0x0002
#define ECS_UNSIGNEDNUMERIC   0x0003
#define ECS_TIME              0x0004
#define ECS_DATE              0x0005
#define ECS_CURRENCY          0x0006

/************ Description of above column creation styles **********************

ECS_CENTER				- Centers the text within a column (Left is default)
ECS_RIGHT            - Right justifies the text within a column
ECS_AUTOHSCROLL      - Allows auto scrolling within in cell editing
ECS_COLUMNHEADING    - Specifies a column heading for this column
ECS_HIDDEN           - Creates the column in everyway wxcept that (including
							  memory) but does not show the column.  This can be
							  changed with the EL_SHOWCOLUMN message.
ESC_SORT             - Allows the column to be sorted when the column heading
							  is clicked.  This column then becomes the primry sort
							  and all others are lowered a level.  Sort order is set
							  using EL_SORTCOLUMNORDER. The sort occurs automatically.
ESC_DESCENDSORT      - Allows the column to be sorted in descending order when
							  the column heading is clicked.  This column then becomes
							  the primry sort and all others are lowered a level.
							  Sort order is set using EL_SORTCOLUMNORDER. The sort
							  occurs automatically.
ESC_OWNERSORT        - Specifies that this column order will be specified by the
							  owner (parent) of the window.  This will occur during
							  any sorting (adding a node, complete resort, or a column
							  header click).
ECS_NORESIZECOLUMN   - Prevents column from being resized when control has
							  ELS_RESIZECOLUMN set.

Note: The default data type is a string.
ECS_NUMERIC          - Will interpret incoming data for that comma as a numeric
							  field and will format by placing commas as defined by
							  windows.
ECS_TIME             - Interprets incoming data as a time field and displays
							  as defined by windows.
ECS_DATA             - Interprets incoming data as a date field and displays
							  as defined by windows.
*ECS_CURRENCY         - Interprets incoming data as currency and displays as
							  defined by windows. CURRENTLY NOT IMPLEMENTED
							  
*******************************************************************************/

/****** The following is the various return values that can be returned *******/
/****** after receiving a SendMessage request **********/

#define EL_OKAY          (0)
#define EL_ERR           (-1)
#define EL_ERRSPACE      (-2)

/***************************************************************************/
/* The following is a list of all programmer sendable messages to the      */
/* editable listbox.                                                       */
/* These Messages handle everything from addition to deletion of string    */
/***************************************************************************/

#define EL_ADDSTRING             (WM_USER +0x0001)
#define EL_INSERTSTRING          (WM_USER +0x0002)
#define EL_SETCELLDATA           (WM_USER +0x0003)
#define EL_DELETESTRING          (WM_USER +0x0004)
#define EL_FINDSTRING            (WM_USER +0x0005)
#define EL_RESETCONTENT          (WM_USER +0x0006)
#define EL_GETTEXT               (WM_USER +0x0007)
#define EL_GETCELLTEXT           (WM_USER +0x0008)
#define EL_GETROWTEXT            (WM_USER +0x0009)
#define EL_GETTEXTLEN            (WM_USER +0x000A)
#define EL_REPLACECURTEXT        (WM_USER +0x000B)
#define EL_GETCOUNT              (WM_USER +0x000C)
#define EL_GETVERTICALCOUNT      (WM_USER +0x000D)
#define EL_GETHORIZONTALCOUNT    (WM_USER +0x000E)
#define EL_GETSELCOUNT           (WM_USER +0x000F)
#define EL_SETITEMDATA           (WM_USER +0x0010)
#define EL_GETITEMDATA           (WM_USER +0x0011)
#define EL_GETCURSEL             (WM_USER +0x0012)
#define EL_GETCURROWSEL          (WM_USER +0x0013)
#define EL_GETCURCOLSEL          (WM_USER +0x0014)
#define EL_SETCURSEL             (WM_USER +0x0015)
#define EL_GETSEL                (WM_USER +0x0016)
#define EL_SETSEL                (WM_USER +0x0017)
#define EL_CONTROLHEIGHT         (WM_USER +0x0018)
#define EL_CONTROLSTRUCT         (WM_USER +0x0019)
#define EL_ADDCELLBITMAP         (WM_USER +0x001A)
#define EL_DELETECELLOBJECT      (WM_USER +0x001B)
#define EL_ADDTRANSPARENTBITMAP  (WM_USER +0x001C)
#define EL_SETBITMAPTRANSCOLOR   (WM_USER +0x001D)
#define EL_SETDEFAULTTRANSCOLOR  (WM_USER +0x001E)
#define EL_GETCOLUMNID           (WM_USER +0x001F)
#define EL_GETCOLUMNPOS          (WM_USER +0x0020)
#define EL_RESIZECOLUMN          (WM_USER +0x0021)
#define EL_MOVECOLUMN            (WM_USER +0x0022)
#define EL_LOCKCOLUMNS           (WM_USER +0x0023)
#define EL_SHOWCOLUMN            (WM_USER +0x0024)
#define EL_SORTCOLUMNORDER       (WM_USER +0x0025)
#define EL_GETCOLUMNWIDTHS       (WM_USER +0x0026)
#define EL_GETITEMRECT           (WM_USER +0x0027)

/********************** Parameters Needed for Above Messages ************

--------------------------------------------------------------------------------

EL_ADDSTRING      -Adds a string to the last row in the list at the specified
						 index. To add data to all the cells in a row delimit the
						 cells(strings) with COLUMNSEPS.  If the editable listbox was
						 created using the ELS_SORT the string()s will be put into
						 their appropriate sorted position for all columns supplied.
						  
						Example: Data1*Data2*Data3*Data4* will add the data string to
									each cell starting with zero.	* is short for COLUMNSEP
						Note: When adding to the entire row all delimited cells must
								be strings and will then be converted internally into
								the correct data type (see Column Creation Styles).
								If adding to only on cell pass the data occurding to
								data type (i.e. Pass a string pointer for string,
								a long for numeric data, etc.)

	wParam       -->Horizontal (Y) index. If wParam ==-1 the string is
						 parsed by COLUMNSEP across all cells in the row.
						 If wParam is not -1 the string is put directly into the cell
						 that was specified.
	lParam       -->Pointer to a NULL terminated string.

	Return Value: Zero-based insertion point is returned, otherwise EL_ERR.
					  Return value is EL_ERRSPACE if insufficient space is avaliable
					  to store the string.

--------------------------------------------------------------------------------

EL_INSERTSTRING   -Inserts a string at the row specified in wParam.  If ECS_SORT
						 creation style is not set, the string is inserted where
						 indicated, otherwise it is inserted in its sorted position.
						 This routine inserts a string across an entire row, cells are
						 seperated by COLUMNSEP. To leave a cell untouched place
						 two COLUMNSEPs (with an empty string) in a row.

	wParam        -->Index to insert string (-1 inserts at end of string)7
	lParam        -->Pointer to a NULL terminated string.

	Return Value: Zero-based insertion point is returned, otherwise EL_ERR.
					  Return value is EL_ERRSPACE if insufficient space is avaliable
					  to store the string.

--------------------------------------------------------------------------------

EL_SETCELLDATA    -Sets the cell text in the cell identicated in the EDLB_MSG
                   struct.

	wParam         -->0
	lParam         -->Points to a EDLB_MSG struct that contains cell and buffer
							information.

	Return Value: Message returns the index of the row that was add.  EL_ERR is
					  returned if an error occurred, EL_ERRSPACE is returned if
					  there is insufficient space.

--------------------------------------------------------------------------------

EL_DELETESTRING   -Deletes an entire row from an editable listbox

	wParam       -->0
	lParam       -->Zero based index of string to delete.

	Return Value: The return value is a count of the strings remaining in
					  the list. The return value is EL_ERR if the index parameter
					  specifies an index greater than the number of item in the list.

--------------------------------------------------------------------------------

EL_FINDSTRING     -Finds a string (case insensitive) in the first column of
						 an editable listbox.
						 
	wParam       -->Index of item before the first item to be seached. -1 will
						 search from the beginning of the list.
	lParam       -->Pointer to a NULL terminated string.

	Return Value: The return index of the matched string if in the list, EL_ERR
	              if a match is not found.

--------------------------------------------------------------------------------

EL_RESETCONTENT   -Removes all items from every cell in the editable listbox.

	wParam        -->0
	lParam        -->0L

	Return Value: Message does not return a value.

--------------------------------------------------------------------------------

EL_GETTEXT        -Used for Single Column Control (Listbox like). Retrieves text
						 and inserts into a buffer supplied in lParam (no delimiter
						 added)

	wParam         -->Zero based index of string to retrieve.
	lParam         -->Buffer to copy text into. There must be enough room to
							hold the string. USE EL_GETTEXTLEN to retrive the length
							of the buffer.

	Return Value: Message returns the length of the returned string.  EL_ERR is
					  returned if an invalid index is requested.

--------------------------------------------------------------------------------

EL_GETCELLTEXT     -Gets the contents of a cell identified by an EDLB_MSG struct.

	wParam         -->0
	lParam         -->Points to a EDLB_MSG struct that contains cell and buffer
							information.

	Return Value: Message returns the length of the returned string.  EL_ERR is
					  returned if an invalid index is requested.

--------------------------------------------------------------------------------

EL_GETROWTEXT     -Gets an entire row of strings from the editable listbox.

	wParam         -->Vertical index into the editable listbox.
	lParam         -->Points to a buffer to return the string into.  Columns will
							be seperated by COLUMN_SEP characters.

	Return Value: Message returns the length of the returned string.  EL_ERR is
					  returned if an invalid index is requested.

--------------------------------------------------------------------------------

EL_GETTEXTLEN		-Gets the text length of the specified buffer.

	wParam			-->Column ID to retrieve text length for. (-1) for entire row.
	lParam 			-->Zero based vertical index.

	Return Value: Length in bytes of the specified string.

--------------------------------------------------------------------------------

EL_REPLACECURTEXT  -Replace the text in the currently selected cell with the
						  text in lParam.
						  
	wParam         -->Vertical index into the editable listbox.
   lParam         -->Points to a buffer that will replace the text in index.
							Columns will be seperated by COLUMN_SEP characters.

	Return Value: TRUE if able to replace string, EL_ERR or EL_ERRSPACE if not.

--------------------------------------------------------------------------------

EL_GETCOUNT       -Number of vertical items in the editable listbox.

	wParam       -->0
	lParam       -->0L

	Return Value: The returned count is one greater than the vertical index value
			        of the last item (the index is zero-based).

--------------------------------------------------------------------------------

EL_GETVERTICALCOUNT -Number of vertical items in the editable listbox.

	wParam       -->0
	lParam       -->0L

	Return Value: The returned count is one greater than the vertical index value
					  of the last item (the index is zero-based).

--------------------------------------------------------------------------------

EL_GETHORIZONTALCOUNT -Number of horizontal items in the editable listbox. This
							  is also the number of columns in the editable listbox.

	wParam       -->0
	lParam       -->0L

	Return Value: The returned count is one greater than the horizontal index
					  value of the last item (the index is zero-based).

--------------------------------------------------------------------------------

EL_GETSELCOUNT   -Gets the number of row selected in a mulitple select, row
						addressable editable listbox.
						
	wParam        -->0
	lParam        -->0L

	Return Value: Returns number of selected items in list.  If not a valid
			        editable listbox EL_ERR is returned.

--------------------------------------------------------------------------------

EL_CONTROLHEIGHT  -Sets the height of the editable listbox items

   wParam        -->Height of each control
   lParam        -->0L

   Return Value: Returns TRUE if successful, FALSE if not.

--------------------------------------------------------------------------------

EL_CONTROLSTRCT   -Sets column information, including width, heading and
						 formatting information. Use CONTROl structure to specify
						 information.  This message is used to setup initial
						 information of the columns and must be specified to have
						 a multiple column editable listbox.

	wParam       -->Number of Controls
	lParam       -->Pointer to CONTROL array (contains info on the cells)

	Return Value: Returns number of controls recieved.

--------------------------------------------------------------------------------

EL_SETITEMDATA  -Associates a long value with a row in the editable listbox.

	wParam       -->Index into zero -based row.
	lParam       -->Item value

	Return Value: Previous value associated with row.

--------------------------------------------------------------------------------

EL_GETITEMDATA  -Gets long data associated with an item.

	wParam       -->Index into zero -based row.
	lParam       -->0L

	Return Value: Item data associated with row

--------------------------------------------------------------------------------

EL_GETCURSEL     -Returns the currently selected row and column.

	wParam        -->0
   lParam        -->0L

   Return Value: Returns the currently selected row in the lo-order word
					  and the currently selected column in the hi-order word.
					  Note: Each value is limited to the first 65535 columns
					  or rows.
--------------------------------------------------------------------------------

EL_GETCURROWSEL  -Returns the currently selected row.

	wParam       -->0
	lParam       -->0L

	Return Value: Returns the currently selected row.

--------------------------------------------------------------------------------

EL_GETCURCOLSEL  -Returns the currently selected columns.

	wParam       -->0
	lParam       -->0L

	Return Value: Returns the currently selected row.

--------------------------------------------------------------------------------

EL_SETCURSEL     -Sets the currently selected row (vertical)

	wParam       -->Index of row to hightlight. -1 will remove any selection
	lParam       -->0L

	Return Value: Returns the the selected row of EL_ERR if no selection
					  or an error occurs.

--------------------------------------------------------------------------------

EL_GETSEL           -Gets the current selection status of a multiple select
							editable listbox.  This call only works with row
							addressable editable listboxes (ELS_ROWADDRESSABLE).

	wParam       -->Index of row to return selection status
	lParam       -->0L

	Return Value: If a the item is selected TRUE is returned, FALSE otherwise.
					  EL_ERR is returned if an error occurs.

--------------------------------------------------------------------------------

EL_SETSEL           -Sets the specified row in a multiple selection listbox.
							This call only works with row addressable editable
							listboxes (ELS_ROWADDRESSABLE).

	wParam       -->Index of row to hightlight. -1 will remove any selection
	lParam       -->0L

	Return Value: TRUE is succesfull, EL_ERR is an error.

--------------------------------------------------------------------------------

EL_ADDCELLBITMAP - Adds a solid bitmap to a particular cell at the position
							specified.

	wParam       -->Position within the cell to place the bitmap
	lParam       -->Pointer to a EDLB_MSG Structure which supplies col_id,
						 row_num and data.  Data is the handle to the bitmap.

	Return Value: TRUE if successful and a valid zero based index
					  (i.e can't add a group  position of 3 if there is only 1 group
					  item currently in the cell). EL_ERR if unsuccesful.

Notes: Group position means that that if you add a bitmap at position 0 the
		 bitmap will be displayed first and the text after it.

		 While any allocated text memory will be released, bitmap and other
		 user sent resources will not.  The calling parent must release these.

		 This call works like EL_ADDSTRING.  If you add do an EL_ADDCELLBITMAP
		 3 times to position 0, you will get three bitmaps in a row, not one. If
		 you wish only one use the EL_DELETECELLOBJECT call.

See Also:  EL_ADDTRANSPARENTBITMAP message.

--------------------------------------------------------------------------------

EL_DELETECELLOBJECT - Deletes a data object from the specified cell.

	wParam       -->Position within the cell to delete
	lParam       -->Pointer to a EDLB_MSG Structure which supplies col_id,
						 row_num.

	Return Value: TRUE if successful and a valid zero based index
					  (i.e can't delete a group  position of 3 if there is only
						1 groupitem currently in the cell). EL_ERR if unsuccesful.

Note: Like EL_DELETESTRING, EL_DELETECELLOBJECT will move any subsequent data
      items in after deleting the data object.

--------------------------------------------------------------------------------

EL_ADDTRANSPARENTBITMAP - Adds a transparent bitmap to a cell at a specified
								  position

	wParam       -->Position within the cell to place the bitmap
	lParam       -->Pointer to a EDLB_MSG Structure which supplies col_id,
						 row_num and data.  Data is the handle to the bitmap.

	Return Value: TRUE if successful, EL_ERR if error.

See Also: EL_ADDCELLBITMAP message.

--------------------------------------------------------------------------------

EL_SETBITMAPTRANSCOLOR -Sets the transparent color for the specified bitmap.

	wParam        -->Bitmap Handle
	lParam        -->COLORREF handle - color to make transparent.

	Return Value: TRUE if successful (valid bitmap), FALSE if not.

Note:  The transparent color is only specified once per bitmap and is used
		 throughout any displaying of that bitmap.

--------------------------------------------------------------------------------

EL_SETDEFAULTTRANSCOLOR -Sets the default transparent color for all bitmaps.

	wParam        -->0
	lParam        -->COLORREF Handle - default transparent color

	Return Value: No return value:

Note: When a default transparent color is specified after any transparent
		bitmap has been added with no set transparent color those bitmaps will
		have a transparent color of the one specified with this message. 

--------------------------------------------------------------------------------

EL_GETCOLUMNID     -Returns the id of the column at the specified position

	wParam       -->Column Position (Zero column is left most column)
	lParam       -->OL

	Return Value: Column ID of the specified column, if invalid EL_ERR is returned.

--------------------------------------------------------------------------------

EL_GETCOLUMNPOS    -Returns the position (Zero based) of the specified column

	wParam       -->Column ID
	lParam       -->OL

	Return Value: Column Position of the specified column,
					  if invalid EL_ERR is returned.

--------------------------------------------------------------------------------

EL_RESIZECOLUMN    -Resizes the specified column

	wParam       -->Redraw Flag, TRUE will redraw the control
	lParam       -->LOWORD -Column ID
						 HIWORD -Width of column

	Return Value: TRUE if column size was changed, FALSE if not.

Note: A column resize notification message is sent out upon succesful resizing.

--------------------------------------------------------------------------------

EL_MOVECOLUMN		-Will move the specified column to it's new position

	wParam        -->Redraw Flag, TRUE will redraw the control
	lParam       -->LOWORD -Column ID
						 HIWORD -New position of column

Note: A column move notification message is sent out upon succesful moving.

--------------------------------------------------------------------------------

EL_LOCKCOLUMNS     -Locks x amount of columns. Keeps them from being scrolled
						  while columns to the right scroll underneath.  This message
						  locks the first N viewable columns.  Any hidden columns are
						  not counted when locked columns is set.

	wParam       -->number of columns to lock
	lParam       -->0L

	Return Value: Number of Columns Locked

--------------------------------------------------------------------------------

EL_SHOWCOLUMN      -Sets a columns visibilty state.  Sorting priority with in
						  this column remains constant.

	wParam       -->State to show column. Zero is Hidden. One is Show
	lParam       -->Column to change state of.

	Return Value: TRUE if column state was changed, FALSE if not.

--------------------------------------------------------------------------------

EL_SORTCOLUMNORDER  -Sets the order in which columns are ordered.  For example
							stating a lParam of 0/1 states a primary sort of the first
							column.  Specifying 3/2 for lParam will make the third
							column the secondary sort.

	wParam       -->States if list should be immediately resorted.
	lParam       -->LOWORD -Column ID
						 HIWORD -Column ordering position (a sort order of -1 removes any
						 sorting).  Primary sort if 1 (one).

	Return Value: TRUE if succesful, FALSE if not.

	Note: The default value is the first column is the primary sort.  If a column
			set with ESC_SORT is clicked in the column header that becomes the
			primary key and all other sort specified columns are lowered.
			When a column order is set, any column that has that currently has that
			sort priority down to the previous sort priority of the updated column
			will be lowered one level.  For example, if a columns sort priority is
			being upped from 3 to 1 the columns that currently have priority 1 and
			2 will be downgraded to 2 and 3 repectively.

--------------------------------------------------------------------------------

EL_GETCOLUMNWIDTHS -Will return the widths of every column from left to right.
						  To get the number of columns use EL_GETHORIZONTALCOUNT. Use
						  EL_GETCOLUMNID to get the id of the column at the specified
						  index.

	wParam       -->0
	lParam	    -->Array of integers large enough to hold all column widths.

	Return Value: No Return Value

--------------------------------------------------------------------------------

EL_GETITEMRECT     -Returns the rectangle bounding the specified rectangle.
						  Values are relative to the upper left hand corner of the
						  window.  This value will include any labels along the top
						  and left side of the control.

	wParam       -->Zero based index of item
	lParam       -->Long pointer to a rectangle

	Return Value: TRUE if able to retrive rect, EL_ERR if not
	 
--------------------------------------------------------------------------------

************************** End Description Section ****************/

/***************** Message Notification Section *******************/

#define ELN_SELCHANGE         0x0001
#define ELN_DBLCLK            0x0002
#define ELN_KILLFOCUS         0x0003
#define ELN_SETFOCUS          0x0004
#define ELN_ERRSPACE          0x0005
#define ELN_CHANGE            0x0010
#define ELN_EDITKILLFOCUS     0x0011
#define ELN_MOVECOLUMN        0x0020
#define ELN_RESIZECOLUMN      0x0021
#define ELN_BEGINSORT         0x0022
#define ELN_ENDSORT           0x0023

/******************** Start of message Description Section ********

Note: The message notification must combine the aspects of three seperate
		controls.  First the editable listbox must send message appropriate
		for a listbox (i.e. ELN_SELCHANGE - cursor has moved).  Also the
		control must send messages associated with the edit box (in cell
		editing) (i.e. ELN_CHANGE - text enter in cell).  Lastly the editable
		listbox must notify the part of unique message situations
		(i.e. ELN_MOVECOLUMN),

Note2: All notification messages are recieved through WM_COMMAND

******************** List Box Type Notification Messages ***************

ELN_SELCHANGE      -Sent when the cursor in the editable listbox is about
						  to change.

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_SELCHANGE in the high word.

--------------------------------------------------------------------------------

ELN_DBLCLK         -Sent when a the user has double clicked on a cell region

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_DBLCLK in the high word.
--------------------------------------------------------------------------------

ELN_SETFOCUS       -Sent when the editable listbox gains the input focus

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_SETFOCUS in the high word.

--------------------------------------------------------------------------------

ELN_KILLFOCUS      -Sent when the editable listbox loses the input focus

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_KILLFOCUS in the high word.

--------------------------------------------------------------------------------

ELN_ERRPSACE       -Sent when the editable listbox gain allocate enough
						  memory to meet the specific request

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_ERRSPACE in the high word.

--------------------------------------------------------------------------------

*********************** Edit Type Notification Messages ******************

--------------------------------------------------------------------------------

ELN_CHANGE       -Sent when the edit field (in cell editing) is displaying
						altered text

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_CHANGE in the high word.

--------------------------------------------------------------------------------

ELN_EDITKILLFOCUS -Sent when the edit field (in cell editing) has lost
						 input focus

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_EDITKILLFOCUS in the high word.

--------------------------------------------------------------------------------

*********************** Edit Type Notification Messages ******************

--------------------------------------------------------------------------------

ELN_MOVECOLUMN     -Sent when a column has been moved

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
			           and specifies ELN_MOVECOLUMN in the high word.

--------------------------------------------------------------------------------

ELN_RESIZECOLUMN   -Sent when a column has been resized

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_RESIZECOLUMN in the high word.

--------------------------------------------------------------------------------

ELN_BEGINSORT     -Sent when any type of row sorting has started

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_BEGINSORT in the high word.

--------------------------------------------------------------------------------

ELN_ENDSORT        -Sent when sorting has been completed

	wParam       --> Specifies the identifier of the editable listbox
	lParam       --> Specifies handle of editable listbox in the low word,
						  and specifies ELN_ENDSORT in the high word.

--------------------------------------------------------------------------------

************************** End Description Section ****************/

#define WM_EDLBCOMPAREITEM       (WM_USER +0x2800)

/************************ Start of Sort message area **************

WM_EDLBCOMPAREITEM  -Message sent to the parent when the editable listbox is
						  performing a sort.  A EDLB_COMPAREITEMSTRUCT structure is
						  sent with the comparing data items.
	wParam       --> 0L
	lParam       --> Pointer to an EDLB_COMPAREITEMSTRUCT structure.

	Return Value: -1 -Item1 preceeds Item2 in sort order
						0 -Item1 and Item2 are equivalent
						1 -Item1 follows Item2 in sort order.

************************ Start of Sort message area **************/
#endif

